@@ -28,7 +28,7 @@ from sqlalchemy import (Boolean, Column, DateTime, Enum, ForeignKey,
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import orm
 
-from ironic_inspector import conf  # noqa
+
 from ironic_inspector import introspection_state as istate
 
 
@@ -134,6 +134,14 @@ class RuleAction(Base):
         return res
 
 
+class IntrospectionData(Base):
+    __tablename__ = 'introspection_data'
+    uuid = Column(String(36), ForeignKey('nodes.uuid'), primary_key=True)
+    processed = Column(Boolean, default=False, primary_key=True)
+    data = Column(db_types.JsonEncodedDict(mysql_as_long=True),
+                  nullable=True)
+
+
 def init():
     """Initialize the database.
 
