@@ -11,6 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import functools
 import os
 import random
 import re
@@ -18,7 +19,6 @@ import re
 import flask
 from oslo_utils import strutils
 from oslo_utils import uuidutils
-import six
 
 from ironic_inspector import api_tools
 from ironic_inspector.common import context
@@ -124,7 +124,7 @@ def error_response(exc, code=500):
 
 
 def convert_exceptions(func):
-    @six.wraps(func)
+    @functools.wraps(func)
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
@@ -229,7 +229,7 @@ def api(path, is_public_api=False, rule=None, verb_to_rule_map=None,
     def outer(func):
         @_app.route(path, **flask_kwargs)
         @convert_exceptions
-        @six.wraps(func)
+        @functools.wraps(func)
         def wrapper(*args, **kwargs):
             flask.request.context = context.RequestContext.from_environ(
                 flask.request.environ,
