@@ -14,6 +14,7 @@
 """Base code for PXE boot filtering."""
 
 import contextlib
+import functools
 
 from automaton import exceptions as automaton_errors
 from automaton import machines
@@ -22,7 +23,6 @@ from futurist import periodics
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_log import log
-import six
 import stevedore
 
 from ironic_inspector.common.i18n import _
@@ -74,7 +74,7 @@ State_space = [
 def locked_driver_event(event):
     """Call driver method having processed the fsm event."""
     def outer(method):
-        @six.wraps(method)
+        @functools.wraps(method)
         def inner(self, *args, **kwargs):
             with self.lock, self.fsm_reset_on_error() as fsm:
                 fsm.process_event(event)
@@ -202,9 +202,6 @@ class BaseFilter(interface.FilterDriver):
 class NoopFilter(BaseFilter):
     """A trivial PXE boot filter."""
 
-    def get_periodic_sync_task(self):
-        return None
-
 
 _DRIVER_MANAGER = None
 
