@@ -19,7 +19,6 @@ import jsonschema
 from oslo_db import exception as db_exc
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import six
 from sqlalchemy import orm
 
 from ironic_inspector.common.i18n import _
@@ -196,19 +195,13 @@ class IntrospectionRule(object):
             ext = ext_mgr[act.action].obj
 
             for formatted_param in ext.FORMATTED_PARAMS:
-                value = act.params.get(formatted_param)
-                if not value or not isinstance(value, six.string_types):
-                    continue
-
-                # NOTE(aarefiev): verify provided value with introspection
-                # data format specifications.
-                # TODO(aarefiev): simple verify on import rule time.
                 try:
-                    act.params[formatted_param] = value.format(data=data)
-                except KeyError as e:
-                    raise utils.Error(_('Invalid formatting variable key '
-                                        'provided: %s') % e,
-                                      node_info=node_info, data=data)
+                    initial = act.params[formatted_param]
+                except KeyError:
+                    # Ignore parameter that wasn't given.
+                    continue
+                else:
+                    act.params[formatted_param] = _format_value(initial, data)
 
             LOG.debug('Running action `%(action)s %(params)s`',
                       {'action': act.action, 'params': act.params},
@@ -219,6 +212,38 @@ class IntrospectionRule(object):
                   node_info=node_info, data=data)
 
 
+def _format_value(value, data):
+    """Apply parameter formatting to a value.
+
+    Format strings with the values from `data`. If `value` is a dict or
+    list, any string members (and any nested string members) will also be
+    formatted recursively. This includes both keys and values for dicts.
+
+    :param value: The string to format, or container whose members to
+                  format.
+    :param data: Introspection data.
+    :returns: `value`, formatted with the parameters from `data`.
+    """
+    if isinstance(value, str):
+        # NOTE(aarefiev): verify provided value with introspection
+        # data format specifications.
+        # TODO(aarefiev): simple verify on import rule time.
+        try:
+            return value.format(data=data)
+        except KeyError as e:
+            raise utils.Error(_('Invalid formatting variable key '
+                                'provided in value %(val)s: %(e)s'),
+                              {'val': value, 'e': e}, data=data)
+    elif isinstance(value, dict):
+        return {_format_value(k, data): _format_value(v, data)
+                for k, v in value.items()}
+    elif isinstance(value, list):
+        return [_format_value(v, data) for v in value]
+    else:
+        # Assume this is a 'primitive' value.
+        return value
+
+
 def _parse_path(path):
     """Parse path, extract scheme and path.
 
@@ -240,41 +265,17 @@ def _parse_path(path):
     return scheme, path
 
 
-def create(conditions_json, actions_json, uuid=None,
-           description=None):
-    """Create a new rule in database.
+def _validate_conditions(conditions_json):
+    """Validates conditions from jsonschema.
 
-    :param conditions_json: list of dicts with the following keys:
-                            * op - operator
-                            * field - JSON path to field to compare
-                            Other keys are stored as is.
-    :param actions_json: list of dicts with the following keys:
-                         * action - action type
-                         Other keys are stored as is.
-    :param uuid: rule UUID, will be generated if empty
-    :param description: human-readable rule description
-    :returns: new IntrospectionRule object
-    :raises: utils.Error on failure
+    :returns: a list of conditions.
     """
-    uuid = uuid or uuidutils.generate_uuid()
-    LOG.debug('Creating rule %(uuid)s with description "%(descr)s", '
-              'conditions %(conditions)s and actions %(actions)s',
-              {'uuid': uuid, 'descr': description,
-               'conditions': conditions_json, 'actions': actions_json})
-
     try:
         jsonschema.validate(conditions_json, conditions_schema())
     except jsonschema.ValidationError as exc:
         raise utils.Error(_('Validation failed for conditions: %s') % exc)
 
-    try:
-        jsonschema.validate(actions_json, actions_schema())
-    except jsonschema.ValidationError as exc:
-        raise utils.Error(_('Validation failed for actions: %s') % exc)
-
     cond_mgr = plugins_base.rule_conditions_manager()
-    act_mgr = plugins_base.rule_actions_manager()
-
     conditions = []
     reserved_params = {'op', 'field', 'multiple', 'invert'}
     for cond_json in conditions_json:
@@ -307,7 +308,20 @@ def create(conditions_json, actions_json, uuid=None,
                            cond_json.get('multiple', 'any'),
                            cond_json.get('invert', False),
                            params))
+    return conditions
 
+
+def _validate_actions(actions_json):
+    """Validates actions from jsonschema.
+
+    :returns: a list of actions.
+    """
+    try:
+        jsonschema.validate(actions_json, actions_schema())
+    except jsonschema.ValidationError as exc:
+        raise utils.Error(_('Validation failed for actions: %s') % exc)
+
+    act_mgr = plugins_base.rule_actions_manager()
     actions = []
     for action_json in actions_json:
         plugin = act_mgr[action_json['action']].obj
@@ -320,6 +334,33 @@ def create(conditions_json, actions_json, uuid=None,
                               {'act': action_json['action'], 'error': exc})
 
         actions.append((action_json['action'], params))
+    return actions
+
+
+def create(conditions_json, actions_json, uuid=None,
+           description=None):
+    """Create a new rule in database.
+
+    :param conditions_json: list of dicts with the following keys:
+                            * op - operator
+                            * field - JSON path to field to compare
+                            Other keys are stored as is.
+    :param actions_json: list of dicts with the following keys:
+                         * action - action type
+                         Other keys are stored as is.
+    :param uuid: rule UUID, will be generated if empty
+    :param description: human-readable rule description
+    :returns: new IntrospectionRule object
+    :raises: utils.Error on failure
+    """
+    uuid = uuid or uuidutils.generate_uuid()
+    LOG.debug('Creating rule %(uuid)s with description "%(descr)s", '
+              'conditions %(conditions)s and actions %(actions)s',
+              {'uuid': uuid, 'descr': description,
+               'conditions': conditions_json, 'actions': actions_json})
+
+    conditions = _validate_conditions(conditions_json)
+    actions = _validate_actions(actions_json)
 
     try:
         with db.ensure_transaction() as session:
